******************************************************************************
*** "Economic Self-Interest, Information, and Trade Policy Preferences: 
***  Evidence from an Experiment in Tunisia"
***  Review of International Political Economy
***  November 30, 2018
***  MULTIPLE IMPUTATION ANALYSIS
******************************************************************************

clear all
set more off

* Set directory
cd ""

** Imputation Models
use "data/ripe_imputed.dta", clear

** Declare imputed and unimputed variables
mi import flong, id(idcode enumfe) m(imp) imputed(female-treatpool tradeexp_dich-log_fdifirms)

mi set flong
mi describe
mi varying

** ASSIGN VARIABLE LABELS
la var age "Age"
la var age2 "Age2"
la var female "Female"
la var educ "Education"
la var graduate "Education"
	la define educl 1 "Low Education" 2 "High Education"
	la val graduate educl
la var re_islam_pca "Cons. Islam"
la var hiskill "High Skill"
la var relig_hilo "Religiosity"
la var re_islam_pca "Cons. Islam"
la var re_islam_pca_dich "Cons. Islam"
	la define consislam 1 "Low Cons. Islam" 2 "High Cons. Islam"
la var sociotropic_v2 "Sociotropic (high)" 
	la val sociotropic_v2 stropicvalue
la var sociotropic_ordinal "Sociotropic (Ordinal)"	
la var re_relig_pca_dich "Religiosity PCA"
	la define religiosity 1 "Low Religiosity" 2 "High Religiosity"
la var treatpool "Treatment"
	la define treatments 1 "Control" 2 "Treatment"
	la val treatpool treatments
la var union_mem "Union Member"
	la define unionmem 1 "Not a Union Member" 2 "Union Member"
	la val union_mem unionmem
la var informal_ordinal "Informal"
la var informal_broad "Informal (Binary)"
la var rec_natl1 "Nationalism"
la var natl1_dich "Nationalism (Binary)"
la var polideo3_1 "Anti-West"
la var polideo3_1_dich "Anti-West (Binary)"
la var monthincome "Income"

la define sectors 1 "Exporters" 2 "Import-Competing" 3 "Non-Traded" 4 "Public"
la val bin_all sectors

la var idcode "ID"
la var enumfe "Enumerator ID"
la var governorate "Governorate"
la var log_income "Log(Monthly Income)"
la var bin_exports "Export sector"
la var bin_imports "Imports sector"
la var bin_public "Public sector"
la var bin_nontraded "Nontraded sector"
la var bin_all "Sector"
la var treatpool "Treatment"
la var enumfe "Enumerator ID"
la var trans_gind2_1 "Pre-Exp: Open Tunisia's market to intl trade, good/bad for your/MIEs job?"
la var trans_gind2_2 "Pre-Exp: Open Tunisia's market to intl trade, good/bad for your/MIEs firm?"
la var trans_gind2_3 "Pre-Exp: Open Tunisia's market to intl trade, good/bad for the Tunisian economy?"
la var trans_tradeexp "Trade Experiment (0-100): Answer (combines all treatments and bins)."
la var m1pass "Passed Manipulation Check"
la var tradeexp_dich "Trade Experiment (0/1): Answer (combines all treatments and bins)." 
la var gvc_25_recode "GVC"
la var off_shore "Off-Shore"
la var foreign_firms "FDI Firms"
la var log_fdifirms "Log(FDI Firms)"

local control1 "age age2 female educ hiskill"
local control2 "age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" 
local controls "base full"

forval c = 1/2 {

	mi estimate, cmdok post: reg trans_tradeexp treatpool##ib4.bin_all `control`c'' i.governorate, vce(cluster governorate) 
			est store `:word `c' of `controls''_FE_Gov_1_all
			
			
	qui{
				* Difference-in-Difference Estimations
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) // export vs. import
					local e_exim_`v'_`c' = round(r(estimate), 0.01)
					local p_exim_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_exim_`v'_`c' = round(r(se), 0.01)
					estadd scalar exim_e = `e_exim_`v'_`c''
					estadd local exim_se = "(`se_exim_`v'_`c'')"
					estadd scalar exim_p = `p_exim_`v'_`c''
					
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // export vs. nontraded
					local e_exno_`v'_`c' = round(r(estimate), 0.01)
					local p_exno_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_exno_`v'_`c' = round(r(se), 0.01)
					estadd scalar exno_e = `e_exno_`v'_`c''
					estadd local exno_se = "(`se_exno_`v'_`c'')"
					estadd scalar exno_p = `p_exno_`v'_`c''
				
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // export vs. public
					local e_expu_`v'_`c' = round(r(estimate), 0.01)
					local p_expu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_expu_`v'_`c' = round(r(se), 0.01)
					estadd scalar expu_e = `e_expu_`v'_`c''
					estadd local expu_se = "(`se_expu_`v'_`c'')"
					estadd scalar expu_p = `p_expu_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // import vs. nontraded
					local e_imno_`v'_`c' = round(r(estimate), 0.01)
					local p_imno_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local  se_imno_`v'_`c' = round(r(se), 0.01)
					estadd scalar imno_e = `e_imno_`v'_`c''
					estadd local imno_se = "(`se_imno_`v'_`c'')"
					estadd scalar imno_p = `p_imno_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // import vs. public
					local e_impu_`v'_`c' = round(r(estimate), 0.01)
					local p_impu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_impu_`v'_`c' = round(r(se), 0.01)
					estadd scalar impu_e = `e_impu_`v'_`c''
					estadd local impu_se = "(`se_impu_`v'_`c'')"
					estadd scalar impu_p = `p_impu_`v'_`c''
					
				qui lincom (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // nontraded vs. public
					local e_nopu_`v'_`c' = round(r(estimate), 0.01)
					local p_nopu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_nopu_`v'_`c' = round(r(se), 0.01)
					estadd scalar nopu_e = `e_nopu_`v'_`c''
					estadd local nopu_se = "(`se_nopu_`v'_`c'')"
					estadd scalar nopu_p = `p_nopu_`v'_`c''

					}
			
			di "`:word `c' of `controls''|Exporters vs. Importers|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_exim_`v'_`c''|`se_exim_`v'_`c''|`p_exim_`v'_`c''"
			di "`:word `c' of `controls''|Exporters vs. Non-traders|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_exno_`v'_`c''|`se_exno_`v'_`c''|`p_exno_`v'_`c''"
			di "`:word `c' of `controls''|Exporters vs. Public|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_expu_`v'_`c''|`se_expu_`v'_`c''|`p_expu_`v'_`c''"
			di "`:word `c' of `controls''|Importers vs. Non-traders|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_imno_`v'_`c''|`se_imno_`v'_`c''|`p_imno_`v'_`c''"
			di "`:word `c' of `controls''|Importers vs. Public|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_impu_`v'_`c''|`se_impu_`v'_`c''|`p_impu_`v'_`c''"
			di "`:word `c' of `controls''|Non-traders vs. Public|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_nopu_`v'_`c''|`se_nopu_`v'_`c''|`p_nopu_`v'_`c''"
				
	}
	
	
**** Table A17 (MI-Main Effects, OLS, Governorate Fixed Effects)
 esttab base_FE_Gov_1_all full_FE_Gov_1_all  using "output/tableA17.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2, fmt(0 3)) /*
	*/ noomitted nobaselevels drop(*.governorate)  unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) /*
	*/ title(Main Effects - Support for Trade (MI) \label{maineff:mi}) nomtitles /*
	*/ addnote("OLS estimates with robust standard errors clustered by governorate. Control and Public Sector are reference categories. Governorate Fixed effects not shown.")

**** Table A18 (MI-Difference-in-Differences, OLS, Governorate Fixed Effects)
esttab base_FE_Gov_1_all full_FE_Gov_1_all using "output/tableA18.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(exim_e exim_se exim_p exno_e exno_se exno_p expu_e expu_se expu_p imno_e imno_se imno_p impu_e impu_se impu_p nopu_e nopu_se nopu_p /*
	*/ , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 )) /*
	*/ drop(*)  unstack starlevels(* .1 ** .05 *** .01) label legend substitute(exim_e "Exporters vs. Import-Competing" /*
	*/ exim_se "" exno_e "Exporters vs. Non-Traders" exno_se "" expu_e "Exporters vs. Public" expu_se "" imno_e "Import-Competing vs. Non-Traders" imno_se "" /*
	*/ impu_e "Import-Competing vs. Public" impu_se "" nopu_e "Non-Traders vs. Public" nopu_se "") /*
	*/ title(Difference-in-Differences (MI): Support for Trade  \label{maineff:did:mi}) nomtitles /*
	*/ addnote("Difference-in-Differences (DID) between sectors, calculated from OLS estimates reported in Table A17. Control and Public Sector are reference categories.")
 		

